@@ -199,7 +199,7 @@ main (int argc, char *argv[])
 	{ "individual-totals", no_argument, NULL, 11 },
 	{ "file", required_argument, NULL, 12 },
 	{ "compatibility", no_argument, NULL, 13 },
-	{ "year", no_argument, NULL, 14 },
+	{ "print-year", no_argument, NULL, 14 },
 	{ "all-days", no_argument, NULL, 15 },
 	{ "tw-suspicious", required_argument, NULL, 16 },
 	{ 0, 0, 0, 0 }
@@ -239,7 +239,7 @@ main (int argc, char *argv[])
 	  break;
 	case 'V':
 	case 8:
-	  printf ("%s: GNU Accounting Utilities (beta release %d.%d)\n",
+	  printf ("%s: GNU Accounting Utilities (release %d.%d)\n",
 		  program_name, RELEASE_MAJOR, RELEASE_MINOR);
 	  exit (0);
 	  break;
@@ -349,7 +349,7 @@ give_usage (void)
   char *usage = "\
 Usage: %s [-dhpVy] [-f <file>] [people] ...\n\
        [--daily-totals] [--individual-totals] [--file <file>]\n\
-       [--complain] [--reboots] [--supplants] [--timewarps] [--year]\n\
+       [--complain] [--reboots] [--supplants] [--timewarps] [--print-year]\n\
        [--compatibility] [--print-zeros] [--debug] [--tw-leniency <value>]\n\
        [--tw-suspicious <value>] [--version] [--help]\n";
   
