@@ -83,7 +83,7 @@ main (int argc, char *argv[])
 	{
 	case 'V':
 	case 1:
-	  printf ("%s: GNU Accounting Utilities (beta release %d.%d)\n",
+	  printf ("%s: GNU Accounting Utilities (release %d.%d)\n",
 		  program_name, RELEASE_MAJOR, RELEASE_MINOR);
 	  exit (0);
 	  break;
