@@ -20,7 +20,11 @@ struct hashtab_elem {
 };
 
 struct hashtab {
-  unsigned long table_size;
+  unsigned long table_size;	/* number of buckets */
+  unsigned long items_hashed;	/* number of items in the table */
+  unsigned long resize_size;	/* num items hashed after which we
+				   should increase the number of
+				   buckets */
   struct hashtab_elem **table;
   int numeric;			/* If nonzero, this is a numeric hash
 				   table, so the length of items
