@@ -210,6 +210,9 @@ enum {
 #if defined(HAVE_ACSTIME) && defined(HAVE_ACUTIME) && defined(HAVE_ACMEM)
   , sort_cpu_storage
 #endif
+#ifdef HAVE_ACETIME
+  , sort_real_time
+#endif
 } sort_type = 
 #if defined(HAVE_ACSTIME) && defined(HAVE_ACUTIME)
        sort_sys_plus_user;
@@ -333,7 +336,9 @@ main (int argc, char *argv[])
 	/* Don't want this if it's the default */
 	{ "sort-num-calls", no_argument, NULL, 18 },
 #endif
-
+#ifdef HAVE_ACETIME
+	{ "sort-real-time", no_argument, NULL, 26 },
+#endif
 	{ 0, 0, 0, 0 }
       };
       
@@ -378,7 +383,7 @@ main (int argc, char *argv[])
 	  break;
 	case 'V':
 	case 2:
-	  printf ("%s: GNU Accounting Utilities (beta release %d.%d)\n",
+	  printf ("%s: GNU Accounting Utilities (release %d.%d)\n",
 		  program_name, RELEASE_MAJOR, RELEASE_MINOR);
 	  exit (0);
 	  break;
@@ -491,6 +496,11 @@ main (int argc, char *argv[])
 	case 25:
 	  usracct_file_name = optarg;
 	  break;
+#ifdef HAVE_ACETIME
+	case 26:
+	  sort_type = sort_real_time;
+	  break;
+#endif
 	case 'h':
 	case 3:
 	  /* This should fall through to default! */
@@ -659,7 +669,10 @@ Usage: %s [ options ] [ file ]\n\
 #if defined(HAVE_ACSTIME) && defined(HAVE_ACUTIME)
                         " [--sort-num-calls]"
 #endif
-                                           "\n\
+#ifdef HAVE_ACETIME
+                                           " [--sort-real-time]"
+#endif
+                                                              "\n\
 \n\
 ";
   
@@ -1313,6 +1326,20 @@ compare_stats_entry (struct stats *s1, struct stats *s2)
 	    ? (s2->user_time + s2->sys_time) * s2->mem_usage
 	    : s2->mem_usage);
       break;
+#endif
+#ifdef HAVE_ACETIME
+    case sort_real_time:
+      if (print_seconds)
+	{
+	  v1 = s1->elapsed_time / (double) s1->num_calls;
+	  v2 = s2->elapsed_time / (double) s2->num_calls;
+	}
+      else
+	{
+	  v1 = s1->elapsed_time;
+	  v2 = s2->elapsed_time;
+	}
+      break;
 #endif
     case sort_num_calls:
       v1 = (double) s1->num_calls;
@@ -1399,6 +1426,8 @@ print_user_list (void)
        he = hashtab_next (&ho), num_users++)
     ;
       
+  num_users++;			/* one for the summary entry */
+
   entry_array = (struct hashtab_elem **)
     xmalloc (sizeof (struct hashtab_elem *) * num_users);
 
@@ -1412,8 +1441,6 @@ print_user_list (void)
       entry_array[which++] = he;
     }
   
-  num_users++;			/* one for the summary entry */
-
   /* The summary entry should always be first, so don't sort it.
      Remember to correct the number of elements to adjust... */
 
